netapp_ontap.models.aggregate_space API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.aggregate_space`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class AggregateSpaceSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the AggregateSpace object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `block_storage: AggregateSpaceBlockStorage GET POST PATCH`

    The block_storage field of the aggregate_space.

  `cloud_storage: AggregateSpaceCloudStorage GET POST PATCH`

    The cloud_storage field of the aggregate_space.

  `efficiency: AggrSpaceEfficiency GET POST PATCH`

    The efficiency field of the aggregate_space.

  `efficiency_without_snapshots: SpaceEfficiency GET POST PATCH`

    The efficiency_without_snapshots field of the aggregate_space.

  `efficiency_without_snapshots_flexclones: SpaceEfficiency GET POST PATCH`

    The efficiency_without_snapshots_flexclones field of the aggregate_space.

  `footprint: Size GET`

    A summation of volume footprints (including volume guarantees), in bytes. This includes all of the volume footprints in the block_storage tier and the cloud_storage tier. This is an advanced property; there is an added computational cost to retrieving its value. The field is not populated for either a collection GET or an instance GET unless it is explicitly requested using the fields query parameter containing either footprint or **.

    Example: 608896

  `snapshot: AggregateSpaceSnapshot GET POST PATCH`

    The snapshot field of the aggregate_space.

  `total_provisioned_space: Size GET`

    A summation of volume size, in bytes. This includes all of the volumes inside the aggregate. This is an advanced property; there is an added computational cost to retrieving its value. The field is not populated for either a collection GET or an instance GET unless it is explicitly requested using the fields query parameter containing either total_provisioned_space or **.

    Example: 20971520